@@ -8,105 +8,153 @@ setClassUnion("characterOrNULL", c("character", "NULL"))
 setClassUnion("numericOrNULL", c("numeric", "NULL"))
 setClassUnion("listOrNULLOrnumeric", c("list", "numeric","NULL"))
 setClassUnion("listOrNULLOrcharacter", c("list", "character","NULL"))
+setClassUnion("numericOrNULLOrcharacter", c("numeric", "character","NULL"))
 ### Parameter Object class: x12Parameter ###
 setClass(
     Class="x12Parameter", 
     representation=representation(			
       #period="numeric",
-      span="numericOrNULL",
-      modelspan="numericOrNULL",
-      decimals="numeric",
-      transform="character",
-		  arima="numericOrNULL",
-      sarima="numericOrNULL",
-			automdl="logical",
-      acceptdefault="logical",
-      balanced="logical",
-      maxorder="numeric",
-      maxdiff="numeric",
-      regvariables="characterOrNULL",
-      reguser="characterOrNULL",
-      regfile="characterOrNULL",
-      usertype="characterOrNULL",
-      centeruser="characterOrNULL",
-      regfilestart="characterOrNULL",
-      #regfileformat="characterOrNULL",
-      #tblnames="characterOrNULL",
-      #Rtblnames="characterOrNULL",
-      #addLines="listOrNULL",
-      #use="character",
-			seats="logical",
-      seatsparameter="characterOrNULL",
-      sigmalim="numericOrNULL",
-      outlier="characterOrNULL",
-      critical="listOrNULLOrnumeric",
-      outlier_span="numericOrNULL",
-      outlier_method="characterOrNULL",
-			forecast_years="numericOrNULL",
-      backcast_years="numericOrNULL",
-      forecast_conf="numeric",
-      estimate="logical",
-      estOutofsample="logical",
- 	  	slidingspans="logical",
-      aictest="characterOrNULL",
-      onlytd="logical",
-      sfshort="logical",
-      samode="characterOrNULL",
-      seasonalma="characterOrNULL",
-			trendma="numericOrNULL",
-      x11appendfcst = "logical",
-      x11appendbcst = "logical",
-      x11calendarsigma = "characterOrNULL",
-      x11excludefcst = "logical", 
-      x11final = "character",
-      x11regress = "logical"
+      series.span="numericOrNULLOrcharacter",
+	  series.modelspan="numericOrNULLOrcharacter",
+	  #series.type="characterOrNULL",
+	  #decimals="numeric",
+	transform.function="character",
+	transform.power="numericOrNULL",
+	transform.adjust="characterOrNULL",
+	regression.variables="characterOrNULL",
+	regression.user="characterOrNULL",
+	regression.file="characterOrNULL",
+	regression.usertype="characterOrNULL",
+	regression.centeruser="characterOrNULL",
+	regression.start="numericOrNULLOrcharacter",
+	regression.aictest="characterOrNULL",
+	#outlier="logical",
+	outlier.types="characterOrNULL",
+	outlier.critical="listOrNULLOrnumeric",
+	outlier.span="numericOrNULLOrcharacter",
+	outlier.method="characterOrNULL",	
+	identify="logical",
+	identify.diff="numericOrNULL",
+	identify.sdiff="numericOrNULL",
+	identify.maxlag="numericOrNULL",	
+	arima.model="numericOrNULL",
+	arima.smodel="numericOrNULL",
+	arima.ar="numericOrNULLOrcharacter",
+	arima.ma="numericOrNULLOrcharacter",
+	automdl="logical",
+	automdl.acceptdefault="logical",
+	automdl.balanced="logical",
+	automdl.maxorder="numeric",
+	automdl.maxdiff="numeric",
+	forecast_years="numericOrNULL",
+	backcast_years="numericOrNULL",
+	forecast_conf="numeric",
+	estimate="logical",
+	estimate.outofsample="logical",
+	check="logical",
+	check.maxlag="numericOrNULL",
+	slidingspans="logical",
+	slidingspans.fixmdl="characterOrNULL",
+	slidingspans.fixreg="characterOrNULL",
+	slidingspans.length="numericOrNULL",
+	slidingspans.numspans="numericOrNULL",
+	slidingspans.outlier="characterOrNULL",
+	slidingspans.additivesa="characterOrNULL",
+	slidingspans.start="numericOrNULLOrcharacter",
+	history="logical",
+	history.estimates="characterOrNULL",
+	history.fixmdl="logical",
+	history.fixreg="characterOrNULL",
+	history.outlier="characterOrNULL",
+	history.sadjlags="numericOrNULL",
+	history.trendlags="numericOrNULL",
+	history.start="numericOrNULLOrcharacter",
+	history.target="characterOrNULL",
+	x11.sigmalim="numericOrNULL",
+	x11.type="characterOrNULL",#vorher onlytd="logical"
+	x11.sfshort="logical",
+	x11.samode="characterOrNULL",
+	x11.seasonalma="characterOrNULL",
+	x11.trendma="numericOrNULL",
+	x11.appendfcst="logical",
+	x11.appendbcst="logical",
+	x11.calendarsigma="characterOrNULL",
+	x11.excludefcst="logical", 
+	x11.final="character",
+	x11regression="logical"
+#	seats="logical",
+#	seatsparameter="characterOrNULL"
     ),
     prototype=prototype(
-      #period = 12,
-      span = NULL,
-      modelspan = NULL, 
-      decimals = 2,
-      transform = "auto",
-      arima = NULL,
-      sarima = NULL,
-      automdl = TRUE,
-      acceptdefault=FALSE,
-      balanced=TRUE,
-      maxorder = c(3, 2),
-      maxdiff = c(1, 1),
-      regvariables = NULL,
-      reguser = NULL,
-      regfile = NULL,
-      usertype = NULL,
-      centeruser = NULL,
-      regfilestart = NULL,
-      #tblnames = NULL,
-      #Rtblnames = NULL,
-      #addLines = NULL,
-      #use = "x12",
-      seats = FALSE,
-      seatsparameter = NULL,
-      sigmalim=NULL,
-      critical = NULL,
-      outlier_span = NULL,
-      outlier_method = NULL,
-      forecast_years = 1,
-      backcast_years = NULL,
-      forecast_conf=0.95,
-      estimate = FALSE,
-      estOutofsample = TRUE,
-      slidingspans = FALSE,
-      aictest = NULL,
-      onlytd = FALSE,
-      sfshort = FALSE, 
-      samode = NULL,
-      seasonalma = NULL,
-      trendma = NULL,
-      x11appendfcst = TRUE, 
-      x11appendbcst = FALSE,
-      x11calendarsigma = NULL,
-      x11excludefcst = TRUE, 
-      x11final = "user", x11regress = FALSE
+			series.span=NULL,
+			series.modelspan=NULL,
+			#series.type=NULL,
+			transform.function="auto",
+			transform.power=NULL,
+			transform.adjust=NULL,
+			regression.variables=NULL,
+			regression.user=NULL,
+			regression.file=NULL,
+			regression.usertype=NULL,
+			regression.centeruser=NULL,
+			regression.start=NULL,
+			regression.aictest=NULL,
+			#outlier=FALSE,
+			outlier.types=NULL,
+			outlier.critical=NULL,
+			outlier.span=NULL,
+			outlier.method=NULL,
+			identify=FALSE,
+			identify.diff=NULL,
+			identify.sdiff=NULL,
+			identify.maxlag=NULL,
+			arima.model=NULL,
+			arima.smodel=NULL,
+			arima.ar=NULL,
+			arima.ma=NULL,
+			automdl=TRUE,
+			automdl.acceptdefault=FALSE,
+			automdl.balanced=TRUE,
+			automdl.maxorder=c(3,2),
+			automdl.maxdiff=c(1,1),
+			forecast_years=1,
+			backcast_years=NULL,
+			forecast_conf=.95,
+			estimate=FALSE,
+			estimate.outofsample=TRUE,
+			check=TRUE,
+			check.maxlag=NULL,
+			slidingspans=FALSE,
+			slidingspans.fixmdl=NULL,
+			slidingspans.fixreg=NULL,
+			slidingspans.length=NULL,
+			slidingspans.numspans=NULL,
+			slidingspans.outlier=NULL,
+			slidingspans.additivesa=NULL,
+			slidingspans.start=NULL,
+			history=FALSE,
+			history.estimates=NULL,
+			history.fixmdl=FALSE,
+			history.fixreg=NULL,
+			history.outlier=NULL,
+			history.sadjlags=NULL,
+			history.trendlags=NULL,
+			history.start=NULL,
+			history.target=NULL,
+			x11.sigmalim=c(1.5,2.5),
+			x11.type=NULL,
+			x11.sfshort=FALSE,
+			x11.samode=NULL,
+			x11.seasonalma=NULL,
+			x11.trendma=NULL,
+			x11.appendfcst=TRUE,
+			x11.appendbcst=FALSE,
+			x11.calendarsigma=NULL,
+			x11.excludefcst=TRUE,
+			x11.final="user",
+			x11regression=FALSE
+#			seats=FALSE, 
+#			seatsparameter=NULL
     ),
     validity=function(object) {
       return(TRUE)
@@ -176,6 +224,7 @@ setClass(
       e2="ts",
       d8="ts",
       b1="ts",
+      td="tsOrNULL",
       otl="tsOrNULL",
       sp0="spectrum",
       sp1="spectrum",
@@ -184,7 +233,7 @@ setClass(
       forecast="fbcast",
       backcast="fbcast",
       dg="list",
-      seats="logical",
+#      seats="logical",
       file="character",
       tblnames="character",
       Rtblnames="character"
@@ -201,6 +250,8 @@ setClass(
         e2=new("ts"),
         d8=new("ts"),
         b1=new("ts"),
+#		td=new("ts"),
+#		otl=new("ts"),		
         sp0=new("spectrum"),
         sp1=new("spectrum"),
         sp2=new("spectrum"),
@@ -208,7 +259,7 @@ setClass(
         forecast=new("fbcast"),
         backcast=new("fbcast"),
         dg=new("diagnostics"),
-        seats=new("logical"),
+#        seats=new("logical"),
         file=new("character"),
         tblnames=new("character"),
         Rtblnames=new("character")        
@@ -285,18 +336,18 @@ setMethod(
     f='initialize',
     signature=signature(.Object = "x12BaseInfo"),
     definition=function(.Object,x12path=NULL,x13path=NULL,use="x12",showWarnings=FALSE) {
-      if(is.null(x12path)&&is.null(x13path)&&!exists("x12path",1)&&!exists("x13path",1))
+      if(is.null(x12path)&&is.null(x13path)&&!existd("x12path")&&!existd("x13path"))
         stop("You have to give either x12path or x13path as argument or \n
               specify a variable x12path in the global environment")
-     if(is.null(x12path)&&exists("x12path",1)){
-       if(file.exists(get("x12path",1)))
-         .Object@x12path <- get("x12path",1)
+     if(is.null(x12path)&&existd("x12path")){
+       if(file.exists(getd("x12path")))
+         .Object@x12path <- getd("x12path")
        else
          stop("file specified in global variable x12path does not exist!\n")
     }
-    if(is.null(x13path)&&exists("x13path",1)){
-      if(file.exists(get("x13path",1)))
-        .Object@x13path <- get("x13path",1)
+    if(is.null(x13path)&&existd("x13path")){
+      if(file.exists(getd("x13path")))
+        .Object@x13path <- getd("x13path")
       else
         stop("file specified in global variable x13path does not exist!\n")
     }
@@ -354,7 +405,7 @@ setMethod(
     signature=signature(x = "x12Single"),
     definition=function(x) {
       cat("Name: ",x@tsName,"\n")
-      cat("processed with X12: ",x@firstRun,"\n")
+      cat("processed with x12: ",x@firstRun,"\n")
       print(x@ts)
     }
 )
