@@ -10,52 +10,80 @@ setMethod(
     signature=signature(object = "x12Parameter"),
     definition=function(object, listP) {
       paras <- c(
-          #"period",
-          "span",
-          "modelspan",
-          "decimals",
-          "transform",
-          "arima",
-          "sarima",
-          "automdl",
-          "acceptdefault",
-          "balanced",
-          "maxorder",
-          "maxdiff",
-          "regvariables",
-          "reguser",
-          "regfile",
-          "usertype",
-          "centeruser",
-          "regfilestart",
-          #"tblnames",
-          #"Rtblnames",
-          #"addLines",
-          "seats",
-          "seatsparameter",
-          "sigmalim",
-          "outlier",
-          "critical",
-          "outlier_span",
-          "outlier_method",
-          "forecast_years",
-          "backcast_years",
-          "forecast_conf",
-          "estimate",
-          "estOutofsample",
-          "slidingspans",
-          "aictest",
-          "onlytd",
-          "sfshort",
-          "samode",
-          "seasonalma",
-          "trendma",
-          "x11appendfcst",
-          "x11appendbcst",
-          "x11calendarsigma",
-          "x11excludefcst", 
-          "x11final",
-          "x11regress")
+			  #"period",
+			  "series.span",
+			  "series.modelspan",
+			  #"series.type",
+			  #"decimals",
+			  "transform.function",
+			  "transform.power",
+			  "transform.adjust",
+			  "regression.variables",
+			  "regression.user",
+			  "regression.file",
+			  "regression.usertype",
+			  "regression.centeruser",
+			  "regression.start",
+			  "regression.aictest",
+			  #"outlier",
+			  "outlier.types",
+			  "outlier.critical",
+			  "outlier.span",
+			  "outlier.method",
+			  "identify",
+			  "identify.diff",
+			  "identify.sdiff",
+			  "identify.maxlag",
+			  "arima.model",
+			  "arima.smodel",
+			  "arima.ar",
+			  "arima.ma",
+			  "automdl",
+			  "automdl.acceptdefault",
+			  "automdl.balanced",
+			  "automdl.maxorder",
+			  "automdl.maxdiff",
+			  "forecast_years",
+			  "backcast_years",
+			  "forecast_conf",
+			  "estimate",
+			  "estimate.outofsample",
+			  "check",
+			  "check.maxlag",
+			  "slidingspans",
+			  "slidingspans.fixmdl",
+			  "slidingspans.fixreg",
+			  "slidingspans.length",
+			  "slidingspans.numspans",
+			  "slidingspans.outlier",
+			  "slidingspans.additivesa",
+			  "slidingspans.start",
+			  "history",
+			  "history.estimates",
+			  "history.fixmdl",
+			  "history.fixreg",
+			  "history.outlier",
+			  "history.sadjlags",
+			  "history.trendlags",
+			  "history.start",
+			  "history.target",
+			  "x11.sigmalim",
+			  "x11.type",
+			  "x11.sfshort",
+			  "x11.samode",
+			  "x11.seasonalma",
+			  "x11.trendma",
+			  "x11.appendfcst",
+			  "x11.appendbcst",
+			  "x11.calendarsigma",
+			  "x11.excludefcst",
+			  "x11.final",
+			  "x11regression"
+			  #"tblnames",
+			  #"Rtblnames",
+			  #"seats",
+			  #"seatsparameter"
+				)
       mn <- names(listP)%in%paras
       if(any(!mn)){
         warning("The following parameters could not be matched: ",paste(names(listP)[!mn],collapse=" , "))
@@ -73,52 +101,80 @@ setMethod(
     signature=signature(object = "x12Parameter"),
     definition=function(object, whichP) {
       paras <- c(
-          #"period",
-          "span",
-          "modelspan",
-          "decimals",
-          "transform",
-          "arima",
-          "sarima",
-          "automdl",
-          "acceptdefault",
-          "balanced",
-          "maxorder",
-          "maxdiff",
-          "regvariables",
-          "reguser",
-          "regfile",
-          "usertype",
-          "centeruser",
-          "regfilestart",
-          #"tblnames",
-          #"Rtblnames",
-          #"addLines",
-          "seats",
-          "seatsparameter",
-          "sigmalim",
-          "outlier",
-          "critical",
-          "outlier_span",
-          "outlier_method",
-          "forecast_years",
-          "backcast_years",
-          "forecast_conf",
-          "estimate",
-          "estOutofsample",
-          "slidingspans",
-          "aictest",
-          "onlytd",
-          "sfshort",
-          "samode",
-          "seasonalma",
-          "trendma",
-          "x11appendfcst",
-          "x11appendbcst",
-          "x11calendarsigma",
-          "x11excludefcst", 
-          "x11final",
-          "x11regress")
+			  #"period",
+			  "series.span",
+			  "series.modelspan",
+			  #"series.type",
+			  #"decimals",
+			  "transform.function",
+			  "transform.power",
+			  "transform.adjust",
+			  "regression.variables",
+			  "regression.user",
+			  "regression.file",
+			  "regression.usertype",
+			  "regression.centeruser",
+			  "regression.start",
+			  "regression.aictest",
+			  #"outlier",
+			  "outlier.types",
+			  "outlier.critical",
+			  "outlier.span",
+			  "outlier.method",
+			  "identify",
+			  "identify.diff",
+			  "identify.sdiff",
+			  "identify.maxlag",
+			  "arima.model",
+			  "arima.smodel",
+			  "arima.ar",
+			  "arima.ma",
+			  "automdl",
+			  "automdl.acceptdefault",
+			  "automdl.balanced",
+			  "automdl.maxorder",
+			  "automdl.maxdiff",
+			  "forecast_years",
+			  "backcast_years",
+			  "forecast_conf",
+			  "estimate",
+			  "estimate.outofsample",
+			  "check",
+			  "check.maxlag",
+			  "slidingspans",
+			  "slidingspans.fixmdl",
+			  "slidingspans.fixreg",
+			  "slidingspans.length",
+			  "slidingspans.numspans",
+			  "slidingspans.outlier",
+			  "slidingspans.additivesa",
+			  "slidingspans.start",
+			  "history",
+			  "history.estimates",
+			  "history.fixmdl",
+			  "history.fixreg",
+			  "history.outlier",
+			  "history.sadjlags",
+			  "history.trendlags",
+			  "history.start",
+			  "history.target",
+			  "x11.sigmalim",
+			  "x11.type",
+			  "x11.sfshort",
+			  "x11.samode",
+			  "x11.seasonalma",
+			  "x11.trendma",
+			  "x11.appendfcst",
+			  "x11.appendbcst",
+			  "x11.calendarsigma",
+			  "x11.excludefcst",
+			  "x11.final",
+			  "x11regression"
+			  #"tblnames",
+			  #"Rtblnames",
+			  #"seats",
+			  #"seatsparameter"
+			  )
       
       mn <- whichP%in%paras
       if(any(!mn)){
